import os
import sys
import docx
import pandas as pd

# Change this to your working directory
WORK_DIR = "/home/arslantste/office_workspace"


def extract_tables_from_docx(docx_path, output_excel):
    doc = docx.Document(docx_path)
    tables = doc.tables

    if not tables:
        print("no-tables")
        return False

    with pd.ExcelWriter(output_excel) as writer:
        for i, table in enumerate(tables):
            data = []
            for row in table.rows:
                cells = []
                for cell in row.cells:
                    paragraphs = [p.text.strip() for p in cell.paragraphs if p.text.strip()]
                    cells.append(" ".join(paragraphs) if paragraphs else "")
                data.append(cells)

            if all(all(cell == "" for cell in row) for row in data):
                continue

            df = pd.DataFrame(data)
            df.to_excel(writer, sheet_name=f"Table{i+1}", index=False)
    return True

def full_convert(pdf_path, output_excel):
    if not os.path.exists(pdf_path):
        print("pdf-not-found")
        return

    pdf_filename = os.path.basename(pdf_path)
    docx_temp = os.path.join(WORK_DIR, pdf_filename.replace(".pdf", ".docx"))

    os.environ['HOME'] = WORK_DIR
    os.environ['TMPDIR'] = WORK_DIR

    print(f"[DEBUG] Input PDF: {pdf_path}")
    print(f"[DEBUG] Output DOCX: {docx_temp}")

    convert_cmd = f'/bin/libreoffice --headless --convert-to docx:"MS Word 2007 XML" "{pdf_path}" --outdir "{WORK_DIR}"'
    print(f"[DEBUG] Running: {convert_cmd}")
    os.system(convert_cmd)

    if not os.path.exists(docx_temp):
        print("conversion-failed")
        return

    if extract_tables_from_docx(docx_temp, output_excel):
        print("success")
    else:
        print("fail")

    if os.path.exists(docx_temp):
        os.remove(docx_temp)


if __name__ == "__main__":
    if len(sys.argv) < 3:
        print("Usage: python pdf_to_excel_via_libreoffice.py input.pdf output.xlsx")
    else:
        full_convert(sys.argv[1], sys.argv[2])
